@@ -10,55 +10,17 @@ use std::fs;
 use model::{SqlMap};
 use serde_xml_rs::from_reader;
 use pgsql::connect_db;
-use serde::{Serialize};
+use crate::model::Value;
 
 pub mod utils;
 pub mod model;
 pub mod pgsql;
+pub mod pgsql_dao;
 pub mod oracle;
+pub mod oracle_dao;
 pub mod uodbc;
 
 
-pub enum DB {
-    Oracle(String),
-    Posgresql(String),
-}
-#[derive(Debug)]
-pub enum DbConnStatus {
-    Idle,
-    Active,
-    Disconnected,
-}
-#[derive(Debug, Serialize)]
-pub enum Value {
-    String(String),
-    StringLikeLeft(String),
-    StringLikeRight(String),
-    StringLikeBoth(String),
-    Float(f64),
-    Integer(i64),
-    Bool(bool),
-    Date(String),
-    StringArray(Vec<String>),
-    IntegerArray(Vec<i64>),
-    BareString(String),
-}
-
-pub enum ColumnType {
-    String,
-    Float,
-    Integer,
-    Date,
-}
-pub struct Column {
-    pub name: String,
-    pub column_type: ColumnType,
-}
-pub struct SqlParam<'a> {
-    pub sql_id: &'a str,
-    pub sub_sql_id: &'a str,
-    pub param: &'a HashMap<String, Value>,
-}
 lazy_static! {
     static ref SQL_CACHE: HashMap<String, String> = {
         let mut map = HashMap::new();
