@@ -11,7 +11,9 @@ pub enum OraDaoError {
 
     QueryError(String),
 
-    RedisError(String),
+    ExecutionError(String),
+
+    CommitError(String),
 
 }
 
